==> tekton-model-triggers-v1alpha1-6.5.1-sources.jar: io/fabric8/tekton/triggers/v1alpha1/EventListenerTriggerFluent.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface EventListenerTriggerFluent<A extends EventListenerTriggerFluent<A>> extends Fluent<A>{
  public A addToBindings(Integer index,TriggerSpecBinding item);
  public A setToBindings(Integer index,TriggerSpecBinding item);
  public A addToBindings(io.fabric8.tekton.triggers.v1alpha1.TriggerSpecBinding... items);
  public A addAllToBindings(Collection<TriggerSpecBinding> items);
  public A removeFromBindings(io.fabric8.tekton.triggers.v1alpha1.TriggerSpecBinding... items);
  public A removeAllFromBindings(Collection<TriggerSpecBinding> items);
  public A removeMatchingFromBindings(Predicate<TriggerSpecBindingBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildBindings instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<TriggerSpecBinding> getBindings();
  public List<TriggerSpecBinding> buildBindings();
  public TriggerSpecBinding buildBinding(Integer index);
  public TriggerSpecBinding buildFirstBinding();
  public TriggerSpecBinding buildLastBinding();
  public TriggerSpecBinding buildMatchingBinding(Predicate<TriggerSpecBindingBuilder> predicate);
  public Boolean hasMatchingBinding(Predicate<TriggerSpecBindingBuilder> predicate);
  public A withBindings(List<TriggerSpecBinding> bindings);
  public A withBindings(io.fabric8.tekton.triggers.v1alpha1.TriggerSpecBinding... bindings);
  public Boolean hasBindings();
  public A addNewBinding(String apiversion,String kind,String name,String ref,String value);
  public EventListenerTriggerFluent.BindingsNested<A> addNewBinding();
  public EventListenerTriggerFluent.BindingsNested<A> addNewBindingLike(TriggerSpecBinding item);
  public EventListenerTriggerFluent.BindingsNested<A> setNewBindingLike(Integer index,TriggerSpecBinding item);
  public EventListenerTriggerFluent.BindingsNested<A> editBinding(Integer index);
  public EventListenerTriggerFluent.BindingsNested<A> editFirstBinding();
  public EventListenerTriggerFluent.BindingsNested<A> editLastBinding();
  public EventListenerTriggerFluent.BindingsNested<A> editMatchingBinding(Predicate<TriggerSpecBindingBuilder> predicate);
  public A addToInterceptors(Integer index,TriggerInterceptor item);
  public A setToInterceptors(Integer index,TriggerInterceptor item);
  public A addToInterceptors(io.fabric8.tekton.triggers.v1alpha1.TriggerInterceptor... items);
  public A addAllToInterceptors(Collection<TriggerInterceptor> items);
  public A removeFromInterceptors(io.fabric8.tekton.triggers.v1alpha1.TriggerInterceptor... items);
  public A removeAllFromInterceptors(Collection<TriggerInterceptor> items);
  public A removeMatchingFromInterceptors(Predicate<TriggerInterceptorBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildInterceptors instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<TriggerInterceptor> getInterceptors();
  public List<TriggerInterceptor> buildInterceptors();
  public TriggerInterceptor buildInterceptor(Integer index);
  public TriggerInterceptor buildFirstInterceptor();
  public TriggerInterceptor buildLastInterceptor();
  public TriggerInterceptor buildMatchingInterceptor(Predicate<TriggerInterceptorBuilder> predicate);
  public Boolean hasMatchingInterceptor(Predicate<TriggerInterceptorBuilder> predicate);
  public A withInterceptors(List<TriggerInterceptor> interceptors);
  public A withInterceptors(io.fabric8.tekton.triggers.v1alpha1.TriggerInterceptor... interceptors);
  public Boolean hasInterceptors();
  public EventListenerTriggerFluent.InterceptorsNested<A> addNewInterceptor();
  public EventListenerTriggerFluent.InterceptorsNested<A> addNewInterceptorLike(TriggerInterceptor item);
  public EventListenerTriggerFluent.InterceptorsNested<A> setNewInterceptorLike(Integer index,TriggerInterceptor item);
  public EventListenerTriggerFluent.InterceptorsNested<A> editInterceptor(Integer index);
  public EventListenerTriggerFluent.InterceptorsNested<A> editFirstInterceptor();
  public EventListenerTriggerFluent.InterceptorsNested<A> editLastInterceptor();
  public EventListenerTriggerFluent.InterceptorsNested<A> editMatchingInterceptor(Predicate<TriggerInterceptorBuilder> predicate);
  public String getName();
  public A withName(String name);
  public Boolean hasName();
  public String getServiceAccountName();
  public A withServiceAccountName(String serviceAccountName);
  public Boolean hasServiceAccountName();
  
  /**
   * This method has been deprecated, please use method buildTemplate instead.
   * @return The buildable object.
   */
  @Deprecated
  public TriggerSpecTemplate getTemplate();
  public TriggerSpecTemplate buildTemplate();
  public A withTemplate(TriggerSpecTemplate template);
  public Boolean hasTemplate();
  public EventListenerTriggerFluent.TemplateNested<A> withNewTemplate();
  public EventListenerTriggerFluent.TemplateNested<A> withNewTemplateLike(TriggerSpecTemplate item);
  public EventListenerTriggerFluent.TemplateNested<A> editTemplate();
  public EventListenerTriggerFluent.TemplateNested<A> editOrNewTemplate();
  public EventListenerTriggerFluent.TemplateNested<A> editOrNewTemplateLike(TriggerSpecTemplate item);
  public String getTriggerRef();
  public A withTriggerRef(String triggerRef);
  public Boolean hasTriggerRef();
  public interface BindingsNested<N> extends Nested<N>,TriggerSpecBindingFluent<EventListenerTriggerFluent.BindingsNested<N>>{
    public N and();
    public N endBinding();
    
  }
  public interface InterceptorsNested<N> extends Nested<N>,TriggerInterceptorFluent<EventListenerTriggerFluent.InterceptorsNested<N>>{
    public N and();
    public N endInterceptor();
    
  }
  public interface TemplateNested<N> extends Nested<N>,TriggerSpecTemplateFluent<EventListenerTriggerFluent.TemplateNested<N>>{
    public N and();
    public N endTemplate();
    
  }
  
}

==> tekton-model-triggers-v1alpha1-6.7.1-sources.jar: io/fabric8/tekton/triggers/v1alpha1/EventListenerTriggerFluent.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.Collection;

 /**
  * Generated
  */
public interface EventListenerTriggerFluent<A extends EventListenerTriggerFluent<A>> extends Fluent<A>{
  public A addToBindings(int index,TriggerSpecBinding item);
  public A setToBindings(int index,TriggerSpecBinding item);
  public A addToBindings(io.fabric8.tekton.triggers.v1alpha1.TriggerSpecBinding... items);
  public A addAllToBindings(Collection<TriggerSpecBinding> items);
  public A removeFromBindings(io.fabric8.tekton.triggers.v1alpha1.TriggerSpecBinding... items);
  public A removeAllFromBindings(Collection<TriggerSpecBinding> items);
  public A removeMatchingFromBindings(Predicate<TriggerSpecBindingBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildBindings instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<TriggerSpecBinding> getBindings();
  public List<TriggerSpecBinding> buildBindings();
  public TriggerSpecBinding buildBinding(int index);
  public TriggerSpecBinding buildFirstBinding();
  public TriggerSpecBinding buildLastBinding();
  public TriggerSpecBinding buildMatchingBinding(Predicate<TriggerSpecBindingBuilder> predicate);
  public Boolean hasMatchingBinding(Predicate<TriggerSpecBindingBuilder> predicate);
  public A withBindings(List<TriggerSpecBinding> bindings);
  public A withBindings(io.fabric8.tekton.triggers.v1alpha1.TriggerSpecBinding... bindings);
  public Boolean hasBindings();
  public A addNewBinding(String apiversion,String kind,String name,String ref,String value);
  public EventListenerTriggerFluent.BindingsNested<A> addNewBinding();
  public EventListenerTriggerFluent.BindingsNested<A> addNewBindingLike(TriggerSpecBinding item);
  public EventListenerTriggerFluent.BindingsNested<A> setNewBindingLike(int index,TriggerSpecBinding item);
  public EventListenerTriggerFluent.BindingsNested<A> editBinding(int index);
  public EventListenerTriggerFluent.BindingsNested<A> editFirstBinding();
  public EventListenerTriggerFluent.BindingsNested<A> editLastBinding();
  public EventListenerTriggerFluent.BindingsNested<A> editMatchingBinding(Predicate<TriggerSpecBindingBuilder> predicate);
  public A addToInterceptors(int index,TriggerInterceptor item);
  public A setToInterceptors(int index,TriggerInterceptor item);
  public A addToInterceptors(io.fabric8.tekton.triggers.v1alpha1.TriggerInterceptor... items);
  public A addAllToInterceptors(Collection<TriggerInterceptor> items);
  public A removeFromInterceptors(io.fabric8.tekton.triggers.v1alpha1.TriggerInterceptor... items);
  public A removeAllFromInterceptors(Collection<TriggerInterceptor> items);
  public A removeMatchingFromInterceptors(Predicate<TriggerInterceptorBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildInterceptors instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<TriggerInterceptor> getInterceptors();
  public List<TriggerInterceptor> buildInterceptors();
  public TriggerInterceptor buildInterceptor(int index);
  public TriggerInterceptor buildFirstInterceptor();
  public TriggerInterceptor buildLastInterceptor();
  public TriggerInterceptor buildMatchingInterceptor(Predicate<TriggerInterceptorBuilder> predicate);
  public Boolean hasMatchingInterceptor(Predicate<TriggerInterceptorBuilder> predicate);
  public A withInterceptors(List<TriggerInterceptor> interceptors);
  public A withInterceptors(io.fabric8.tekton.triggers.v1alpha1.TriggerInterceptor... interceptors);
  public Boolean hasInterceptors();
  public EventListenerTriggerFluent.InterceptorsNested<A> addNewInterceptor();
  public EventListenerTriggerFluent.InterceptorsNested<A> addNewInterceptorLike(TriggerInterceptor item);
  public EventListenerTriggerFluent.InterceptorsNested<A> setNewInterceptorLike(int index,TriggerInterceptor item);
  public EventListenerTriggerFluent.InterceptorsNested<A> editInterceptor(int index);
  public EventListenerTriggerFluent.InterceptorsNested<A> editFirstInterceptor();
  public EventListenerTriggerFluent.InterceptorsNested<A> editLastInterceptor();
  public EventListenerTriggerFluent.InterceptorsNested<A> editMatchingInterceptor(Predicate<TriggerInterceptorBuilder> predicate);
  public String getName();
  public A withName(String name);
  public Boolean hasName();
  public String getServiceAccountName();
  public A withServiceAccountName(String serviceAccountName);
  public Boolean hasServiceAccountName();
  
  /**
   * This method has been deprecated, please use method buildTemplate instead.
   * @return The buildable object.
   */
  @Deprecated
  public TriggerSpecTemplate getTemplate();
  public TriggerSpecTemplate buildTemplate();
  public A withTemplate(TriggerSpecTemplate template);
  public Boolean hasTemplate();
  public EventListenerTriggerFluent.TemplateNested<A> withNewTemplate();
  public EventListenerTriggerFluent.TemplateNested<A> withNewTemplateLike(TriggerSpecTemplate item);
  public EventListenerTriggerFluent.TemplateNested<A> editTemplate();
  public EventListenerTriggerFluent.TemplateNested<A> editOrNewTemplate();
  public EventListenerTriggerFluent.TemplateNested<A> editOrNewTemplateLike(TriggerSpecTemplate item);
  public String getTriggerRef();
  public A withTriggerRef(String triggerRef);
  public Boolean hasTriggerRef();
  public interface BindingsNested<N> extends Nested<N>,TriggerSpecBindingFluent<EventListenerTriggerFluent.BindingsNested<N>>{
    public N and();
    public N endBinding();
    
  }
  public interface InterceptorsNested<N> extends Nested<N>,TriggerInterceptorFluent<EventListenerTriggerFluent.InterceptorsNested<N>>{
    public N and();
    public N endInterceptor();
    
  }
  public interface TemplateNested<N> extends Nested<N>,TriggerSpecTemplateFluent<EventListenerTriggerFluent.TemplateNested<N>>{
    public N and();
    public N endTemplate();
    
  }
  
}
